/* istanbul ignore file */
/* tslint:disable */
/* eslint-disable */
import type { BeginUploadRequestDto } from "../models/BeginUploadRequestDto";
import type { BeginUploadResponseDto } from "../models/BeginUploadResponseDto";
import type { CompleteUploadPartRequestDto } from "../models/CompleteUploadPartRequestDto";
import type { FileIdUnboxed } from "../models/FileIdUnboxed";
import type { UploadPartDto } from "../models/UploadPartDto";
import type { UploadPartIndexUnboxed } from "../models/UploadPartIndexUnboxed";
import type { UploadPartListDto } from "../models/UploadPartListDto";
import { request as __request } from "../core/request";

export class FilesService {
  /**
   * Begin a file upload.
   * @param requestBody File upload parameters.
   * @returns BeginUploadResponseDto Success.
   * @throws ApiError
   */
  public static async beginUpload(requestBody: BeginUploadRequestDto): Promise<BeginUploadResponseDto> {
    const result = await __request({
      method: "POST",
      path: `/v1/files`,
      body: requestBody,
      errors: {
        401: `Unauthenticated.`
      }
    });
    return result.body;
  }

  /**
   * Gets a remaining upload part for an in-progress upload.
   * @param fileId
   * @param uploadPartIndex
   * @param requestBody
   * @returns any Success.
   * @throws ApiError
   */
  public static async completeUploadPart(
    fileId: FileIdUnboxed,
    uploadPartIndex: UploadPartIndexUnboxed,
    requestBody: CompleteUploadPartRequestDto
  ): Promise<any> {
    const result = await __request({
      method: "PUT",
      path: `/v1/files/${fileId}/upload_parts/${uploadPartIndex}`,
      body: requestBody,
      errors: {
        401: `Unauthenticated.`,
        403: `Unauthorized.`,
        404: `File or upload part not found.`
      }
    });
    return result.body;
  }

  /**
   * Gets a remaining upload part for an in-progress upload.
   * @param fileId
   * @param uploadPartIndex
   * @returns UploadPartDto Success.
   * @throws ApiError
   */
  public static async getUploadPart(
    fileId: FileIdUnboxed,
    uploadPartIndex: UploadPartIndexUnboxed
  ): Promise<UploadPartDto> {
    const result = await __request({
      method: "GET",
      path: `/v1/files/${fileId}/upload_parts/${uploadPartIndex}`,
      errors: {
        401: `Unauthenticated.`,
        403: `Unauthorized.`,
        404: `File or upload part not found.`
      }
    });
    return result.body;
  }

  /**
   * Lists the remaining upload parts for an in-progress upload. An empty array is returned when the upload is complete.
   * @param fileId
   * @returns UploadPartListDto Success.
   * @throws ApiError
   */
  public static async getUploadParts(fileId: FileIdUnboxed): Promise<UploadPartListDto> {
    const result = await __request({
      method: "GET",
      path: `/v1/files/${fileId}/upload_parts`,
      errors: {
        401: `Unauthenticated.`,
        403: `Unauthorized.`,
        404: `File not found.`
      }
    });
    return result.body;
  }
}
